@@ -21,7 +21,7 @@ class Player:
 		self.rank = Rank(data)
 		self.karma = self.data.get("player", {}).get("karma")
 		self.network_experience = self.data.get("player", {}).get("networkExp")
-		self.network_level = network_level = round((math.sqrt((2 * network_experience) + 30625) / 50) - 2.5, 2)
+		self.network_level = network_level = round((math.sqrt((2 * self.network_experience) + 30625) / 50) - 2.5, 2)
 		
 		#Game statistics
 		self.bedwars = Bedwars(data)
\ No newline at end of file
